@@ -147,6 +147,11 @@ escape.reactivevalues <- function(x, parens = TRUE, collapse = ", ", con = NULL)
   error_embed("shiny inputs", "input$x")
 }
 
+#' @export
+escape.default <- function(x, parens = TRUE, collapse = ", ", con = NULL) {
+  error_embed(obj_type_friendly(x), "x")
+}
+
 # Also used in default_ops() for reactives
 error_embed <- function(type, expr) {
   cli_abort(c(
