@@ -25,7 +25,7 @@ collapse.tbl_sql <- function(x, ...) {
 
 #' @rdname collapse.tbl_sql
 #' @param name Table name in remote database.
-#' @param temporary Should the table be temporary (`TRUE`, the default`) or
+#' @param temporary Should the table be temporary (`TRUE`, the default) or
 #'   persistent (`FALSE`)?
 #' @inheritParams copy_to.src_sql
 #' @inheritParams collect.tbl_sql
@@ -51,7 +51,7 @@ compute.tbl_sql <- function(x,
     name <- unique_table_name()
   }
 
-  name <- as_table_ident(name)
+  name <- as_table_path(name, x$src$con)
   vars <- op_vars(x)
 
   compute_check_indexes(x, indexes)
@@ -128,7 +128,7 @@ collect.tbl_sql <- function(x, ..., n = Inf, warn_incomplete = TRUE, cte = FALSE
   }
 
   sql <- db_sql_render(x$src$con, x, cte = cte)
-  tryCatch(
+  withCallingHandlers(
     out <- db_collect(x$src$con, sql, n = n, warn_incomplete = warn_incomplete, ...),
     error = function(cnd) {
       cli_abort("Failed to collect lazy table.", parent = cnd)
