@@ -1,7 +1,9 @@
 test_that("can print lazy_select_query", {
+  lf <- lazy_frame(x = 1, y = 2)
+
   expect_snapshot(
     lazy_select_query(
-      x = lazy_query_local(tibble(x = 1, y = 2), "df"),
+      x = lf$lazy_query,
       select = quos(
         x_mean = mean(x),
         y2 = y
