@@ -44,28 +44,30 @@ test_that("can refer to default schema explicitly", {
 })
 
 
-test_that("checks for incorrectly specified SQL or schema", {
-  con <- local_sqlite_connection()
-  DBI::dbExecute(con, "CREATE TABLE 'table.with_dot' (a, b, c)")
-
-  expect_message(tbl(con, ident("table.with_dot")), "in a schema")
-  expect_no_message(tbl(con, ident("table.with_dot"), check_from = FALSE))
-
-  expect_error(
-    expect_message(tbl(con, ident("SELECT * FROM table.with_dot")), "an SQL query as source")
-  )
-})
-
 test_that("can distinguish 'schema.table' from 'schema'.'table'", {
   con <- local_sqlite_con_with_aux()
   DBI::dbExecute(con, "CREATE TABLE aux.t1 (x, y, z)")
   DBI::dbExecute(con, "CREATE TABLE 'aux.t1' (a, b, c)")
 
   expect_equal(as.character(tbl_vars(tbl(con, in_schema("aux", "t1")))), c("x", "y", "z"))
-  df <- tbl(con, ident("aux.t1"), check_from = FALSE)
+  df <- tbl(con, ident("aux.t1"))
   expect_equal(as.character(tbl_vars(df)), c("a", "b", "c"))
 })
 
+test_that("useful error if missing I()", {
+  expect_snapshot(
+    tbl(src_memdb(), "foo.bar"),
+    error = TRUE
+  )
+})
+
+test_that("check_from is deprecated", {
+  con <- local_sqlite_connection()
+  DBI::dbExecute(con, "CREATE TABLE x (y)")
+
+  expect_snapshot(tbl(con, "x", check_from = FALSE))
+})
+
 # n_groups ----------------------------------------------------------------
 
 test_that("check basic group size implementation", {
@@ -85,7 +87,7 @@ test_that("ungrouped output", {
 
   out1 <- tbl_sum(mf)
   expect_named(out1, c("Source", "Database"))
-  expect_equal(out1[["Source"]], "table<tbl_sum_test> [?? x 2]")
+  expect_equal(out1[["Source"]], "table<`tbl_sum_test`> [?? x 2]")
   expect_match(out1[["Database"]], "sqlite (.*) \\[:memory:\\]")
 
   out2 <- tbl_sum(mf %>% group_by(x, y))
